#
# spec file for package php7-pear-Net_Socket
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define php_name  php7
%define pear_name Net_Socket
Name:           php7-pear-Net_Socket
Version:        1.2.2
Release:        lp151.3.1
Summary:        Network Socket Interface
License:        BSD-2-Clause
Group:          Productivity/Networking/Web/Servers
Url:            http://pear.php.net/package/%{pear_name}
Source:         http://download.pear.php.net/package/%{pear_name}-%{version}.tgz
BuildRequires:  %{php_name}-devel
BuildRequires:  %{php_name}-pear
Requires:       %{php_name}
Requires:       %{php_name}-pear
Provides:       php-pear-%{pear_name} = %{version}
Provides:       php-pear(%{pear_name}) = %{version}
Obsoletes:      php5-pear-%{pear_name}
BuildArch:      noarch
%if 0%{?suse_version} < 1330
BuildRequires:  %{php_name}-macros
%endif

%description
Net_Socket is a class interface to TCP sockets. It provides blocking
and non-blocking operation, with different reading and writing modes
(byte-wise, block-wise, line-wise and special formats like network
byte-order ip addresses).

%prep
%setup -q -c
mv package.xml %{pear_name}-%{version}

%build

%install
pushd %{pear_name}-%{version}
%{__pear} install --nodeps --offline --packagingroot %{buildroot} package.xml
install -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml
rm -rf %{buildroot}/%{php_peardir}/{doc,tmp}
rm -rf %{buildroot}/%{php_peardir}/.{filemap,lock,registry,channels,depdb,depdblock}
popd
%{php_pear_gen_filelist}

%post
# on `rpm -ivh` PARAM is 1
# on `rpm -Uvh` PARAM is 2
if [ "$1" = "1" ]; then
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml
fi
if [ "$1" = "2" ]; then
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml
fi

%postun
# on `rpm -e` PARAM is 0
if [ "$1" = "0" ]; then
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name}
fi

%files -f %{name}.files

%changelog
* Thu Mar  1 2018 ecsos@opensuse.org
- fix rm -rf line in spec to remove .channels etc. in Factory also
* Mon Sep 11 2017 jweberhofer@weberhofer.at
- Cleaned up spec
* Fri Aug 18 2017 ecsos@opensuse.org
- New upstream release 1.2.2
  * Bug #21178: $php_errormsg is deprecated in PHP 7.2
- changes from 1.2.1
  * Fix BSD-2 licensing
- changes from 1.2.0
  * Change license to BSD-2 Clause
  * Request #17526: License change
- changes from 1.1.0
  * Set minimum PHP version to 5.4.0
  * Set minimum PEAR version to 1.10.1
  * Bug #18262: Incomplete buffer sent with fwrite after bugfix #14619
  * Bug #20113: package.xml does not validate
  * Bug #21031: Warning on connection error(stream_socket_client)
  * PR #7: Fix for "Maximum execution time of 30 seconds exceeded" error
  * PR #8: Make PHP5 compatible
- renamd package to php7-pear-Net_Socket
* Fri Nov  8 2013 aj@ajaissle.de
- New upstream release 1.0.14
  * Fix connecting when host is specified with protocol prefix e.g. ssl://
- Changes between 1.0.10 an 1.0.13:
  * Fix PHP warning and invalid handling of IPv6 addresses
  * Fixed regression in handling of default (not set) timeout (Bug PEAR#19949)
  * IPv6 sockets cannot be used (Bug PEAR#18231)
  * Socket.php errors when sending large emails through Pear Mail (Bug PEAR#18281)
  * 2nd argument of setTimeout() could be optional (Bug PEAR#18436)
  * Setting timeout after connect() doesn't work correctly (Bug PEAR#18437)
  * Wrong PHP version dependency and socket_* function aliases (Bug PEAR#18438)
  * Incomplete gets() method description (Bug PEAR#19557)
* Fri Feb  1 2013 aj@ajaissle.de
- improved spec file to serve more build targets
* Tue Nov 27 2012 Ralf Lang <lang@b1-systems.de>
- SLE11 compat
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Jan 20 2011 chris@computersalat.de
- change to php_pear_gen_filelist macro
* Wed Jan 19 2011 chris@computersalat.de
- pkg rename php5-pear-Net_Socket
- merge with php-pear-net_socket, php5-pear-net_socket
- dr for php-pear-net_socket, php5-pear-net_socket
- added php-macros
- cleanup spec
* Sat Oct 16 2010 Ralf Lang <lang@b1-systems.de>
- updated to upstream version - 1.0.10
  - Configurable newline sequence (PEAR Bug #14181)
  - Make $size parameter to gets() optional (PEAR Bug #14433)
  - Don't overwrite $errstr set by fsockopen (PEAR Bug #14448)
  - Avoid an infinite loop if fwrite() returns 0 (PEAR Bug #14619)
  - CS cleanup (PEAR Bug #14803)
- for more info about changes see ChangeLog
  http://pear.php.net/package/Net_Socket/download/All
* Sat May 30 2009 chris@computersalat.de
- fixed post script
* Thu May 21 2009 chris@computersalat.de
- beautify spec
  o new spec header
  o package rename due to package convention
  o removed php4 stuff, deps
  o added Provides and Obsoletes for old package names.
    This should not break deps
- added stuff to automatically create correct filelist
  o tested against Factory (1120)
  o opensuse >= 1100 complains about
    "directory not owned by package"
- some rpmlint fixes
* Fri Jul 18 2008 suse-tux@gmx.de
- updated to 1.0.9
- major spec changes (registers module in PEARs database etc.)
* Thu Dec  7 2006 suse-tux@gmx.de
- use --packagingroot instead of --installroot
* Sat Jun 10 2006 suse-tux@gmx.de
- make spec file portable for all suse-versions
- adapt name-tag to suse's php-pear-naming-style
* Mon Apr 17 2006 suse-tux@gmx.de
- rebuild on 10.1
* Mon Jan 23 2006 suse-tux@gmx.de
- initial build
